@@ -5,27 +5,25 @@ warnings.filterwarnings(
     'always', module="dli"
 )
 
-__version__ = '1.7.0'
+__version__ = '1.8.3'
+__product__ = "ihsm-datalake"
 
 
 def connect(api_key=None,
             root_url="https://catalogue.datalake.ihsmarkit.com/__api",
+            host=None,
             debug=None,
-            strict=None):
+            strict=None,
+            use_keyring=True):
 
     from dli.client.session import start_session
 
     return start_session(
         api_key,
         root_url=root_url,
-        host=None,
+        host=host,
         debug=debug,
-        strict=strict
+        strict=strict,
+        use_keyring=use_keyring
     )
 
-def set_credentials(DLI_ACCESS_KEY_ID="", DLI_SECRET_ACCESS_KEY=""):
-    if DLI_ACCESS_KEY_ID:
-        os.environ["DLI_ACCESS_KEY_ID"] = DLI_ACCESS_KEY_ID
-
-    if DLI_SECRET_ACCESS_KEY:
-        os.environ["DLI_SECRET_ACCESS_KEY"] = DLI_SECRET_ACCESS_KEY
